jdk/src/share/classes/com/sun/jmx/remote/util/EventClientConnection.java
changeset 1156 bbc2d15aaf7a
parent 1004 5ba8217eb504
child 1247 b4c26443dee5
--- a/jdk/src/share/classes/com/sun/jmx/remote/util/EventClientConnection.java	Wed Sep 03 14:31:17 2008 +0200
+++ b/jdk/src/share/classes/com/sun/jmx/remote/util/EventClientConnection.java	Thu Sep 04 14:46:36 2008 +0200
@@ -25,6 +25,7 @@
 
 package com.sun.jmx.remote.util;
 
+import com.sun.jmx.defaults.JmxProperties;
 import com.sun.jmx.event.EventClientFactory;
 
 import java.lang.reflect.InvocationHandler;
@@ -45,6 +46,7 @@
 import javax.management.ObjectName;
 import javax.management.event.EventClient;
 import javax.management.event.EventClientDelegate;
+import javax.management.namespace.JMXNamespaces;
 
 /**
  * Class EventClientConnection - a {@link Proxy} that wraps an
@@ -63,12 +65,10 @@
     /**
      * A logger for this class.
      **/
-    private static final Logger LOG =
-            Logger.getLogger(EventClientConnection.class.getName());
+    private static final Logger LOG = JmxProperties.NOTIFICATION_LOGGER;
 
-    private static final String NAMESPACE_SEPARATOR = "//";
     private static final int NAMESPACE_SEPARATOR_LENGTH =
-            NAMESPACE_SEPARATOR.length();
+            JMXNamespaces.NAMESPACE_SEPARATOR.length();
 
     /**
      * Creates a new {@code EventClientConnection}.
@@ -212,9 +212,9 @@
         }
 
         final ObjectName mbean = (ObjectName) args[0];
-        final EventClient client = getEventClient();
+        final EventClient evtClient = getEventClient();
 
         // Fails if client is null AND the MBean we try to listen to is
         // in a subnamespace. We fail here because we know this will not
         // work.
         //
@@ -222,15 +222,15 @@
         // earlier agent (JDK 1.6 or earlier), then the EventClient will
         // be null (we can't use the event service with earlier JDKs).
         //
         // In principle a null client indicates that the remote VM is of
         // an earlier version, in which case it shouldn't contain any namespace.
         //
         // So having a null client AND an MBean contained in a namespace is
         // clearly an error case.
         //
-        if (client == null) {
+        if (evtClient == null) {
             final String domain = mbean.getDomain();
-            final int index = domain.indexOf(NAMESPACE_SEPARATOR);
+            final int index = domain.indexOf(JMXNamespaces.NAMESPACE_SEPARATOR);
             if (index > -1 && index <
                     (domain.length()-NAMESPACE_SEPARATOR_LENGTH)) {
                 throw new UnsupportedOperationException(method.getName()+
@@ -256,9 +256,9 @@
             final NotificationFilter filter = (NotificationFilter) args[2];
             final Object handback = args[3];
 
-            if (client != null) {
+            if (evtClient != null) {
                 // general case
-                client.addNotificationListener(mbean,listener,filter,handback);
+                evtClient.addNotificationListener(mbean,listener,filter,handback);
             } else {
                 // deprecated case. Only works for mbean in local namespace.
                 connection.addNotificationListener(mbean,listener,filter,
@@ -274,9 +274,9 @@
 
             switch (nargs) {
             case 2:
-                if (client != null) {
+                if (evtClient != null) {
                     // general case
-                    client.removeNotificationListener(mbean,listener);
+                    evtClient.removeNotificationListener(mbean,listener);
                 } else {
                     // deprecated case. Only works for mbean in local namespace.
                     connection.removeNotificationListener(mbean, listener);
@@ -286,8 +286,8 @@
             case 4:
                 NotificationFilter filter = (NotificationFilter) args[2];
                 Object handback = args[3];
-                if (client != null) {
-                    client.removeNotificationListener(mbean,
+                if (evtClient != null) {
+                    evtClient.removeNotificationListener(mbean,
                                                       listener,
                                                       filter,
                                                       handback);
@@ -212,9 +212,9 @@
 
-        // Fails if client is null AND the MBean we try to listen to is
+        // Fails if evtClient is null AND the MBean we try to listen to is
         // in a subnamespace. We fail here because we know this will not
         // work.
@@ -222,15 +222,15 @@
         // be null (we can't use the event service with earlier JDKs).
         //
-        // In principle a null client indicates that the remote VM is of
+        // In principle a null evtClient indicates that the remote VM is of
         // an earlier version, in which case it shouldn't contain any namespace.
         //
@@ -222,15 +222,15 @@
         // an earlier version, in which case it shouldn't contain any namespace.
         //
-        // So having a null client AND an MBean contained in a namespace is
+        // So having a null evtClient AND an MBean contained in a namespace is
         // clearly an error case.
         //